
<a href="https://pypi.org/project/algo-library/">
<img src="https://img.shields.io/pypi/v/algo-library.svg">
</a>
<a href="https://github.com/TheNewThinkTank/msgspec/blob/main/LICENSE">
<img src="https://img.shields.io/github/license/TheNewThinkTank/algo-lib.svg">
</a>

![PyPI Downloads](https://img.shields.io/pypi/dm/algo-library)
![CI](https://github.com/TheNewThinkTank/algo-lib/actions/workflows/wf.yml/badge.svg)
[![codecov](https://codecov.io/gh/TheNewThinkTank/algo-lib/graph/badge.svg?token=ltMgNt08rV)](https://codecov.io/gh/TheNewThinkTank/algo-lib)
![commit activity](https://img.shields.io/github/commit-activity/m/TheNewThinkTank/algo-lib)
[![GitHub repo size](https://img.shields.io/github/repo-size/TheNewThinkTank/algo-lib?style=flat&logo=github&logoColor=whitesmoke&label=Repo%20Size)](https://github.com/TheNewThinkTank/algo-lib/archive/refs/heads/main.zip)

# algo-lib

Library for common algorithms

## Installation

```BASH
pip install algo-library
```

## Import

```Python
from algo_lib.ml.linear_regression import linear_regression
```

## Usage

see `test/test_ml/test_linear_regression.py`

<!--
## Create a new release

example:

```BASH
git tag 0.0.1
git push origin --tags
```

release a patch:

```BASH
poetry version patch
```

then `git commit`, `git push` and

```BASH
git tag 0.0.2
git push origin --tags
```
-->
